@@ -36,6 +36,6 @@ setMethod("plot",
               tlist[[var]] <- barchart(variable ~ roic, data = data, origin = 0, main = title)
             }
             
-            portfolio:::.trellis.multiplot(tlist)
+            .trellis.multiplot(tlist)
           }
           )
